@@ -35,15 +35,15 @@ def _check() -> None:
 
     # Validate all release notes are parseable for all versions
     # Point of Failure 1
-    changelog_versions = ["Unreleased", *all_versions, "LINKS"]
-    for version, prev_version in zip(
+    changelog_versions = ["Unreleased", *all_versions, None]
+    for new_version, old_version in zip(
         changelog_versions, changelog_versions[1:]
     ):
         try:
-            changelog.get_release_notes(version, prev_version)
-        except:
+            changelog.get_release_notes(new_version, old_version)  # type: ignore
+        except Exception as e:
             raise ValidationException(
-                f"Failed to validate notes for version {version}"
+                f"Failed to validate notes for version {new_version}: {str(e)}."
             )
 
     # Validate there are links in the expected format for all versions
